@@ -17,8 +17,8 @@ from urllib import unquote as _pct_decoded
 
 import rdflib as _rdf
 from spruce.collections import frozendict as _frozendict
-from spruce.lang import require_isinstance as _require_isinstance
-import spruce.uri.duck as _iri_duck
+from spruce.types import require_isinstance as _require_isinstance
+import spruce.iri.goose as _iri_goose
 import sqlalchemy as _sqla
 _sqlaf = _sqla.func
 import sqlalchemy.orm as _sqla_orm
@@ -52,9 +52,9 @@ class DirectMapping(_rdf.store.Store):
         The ORM classes that constitute the domain of this mapping, indexed
         by IRI reference relative to the *base_iri*.  The default is the set
         of classes produced by :func:`rdf2rdb.dm.rdbconn2orm` using the
-        connection produced by :meth:`open` with the given *rdb_args* and
-        *rdb_kwargs*, the *rdb_metadata*, and the *base_iri*, indexed by
-        underlying table name.
+        connection produced by :meth:`open` with the given *configuration*,
+        the *rdb_metadata*, and the *base_iri*, indexed by underlying table
+        name.
     :type orm_classes: {:obj:`str`: :obj:`type`}
 
     :param orm:
@@ -105,6 +105,12 @@ class DirectMapping(_rdf.store.Store):
             subject_cols_props = self._orm_columns_properties[subject_table_iri]
             subject_rels = self._orm_relationships[subject_table_iri]
 
+            # sum:
+            #   * 1 for each class statement (1 for each row)
+            #   * 1 for each literal property statement (1 for each non-null
+            #     attribute of each row)
+            #   * 1 for each reference property statement (1 for each totally
+            #     non-null foreign key value tuple of each row)
             len_ += \
                 self._orm.query\
                  (_sqla.func.count(subject_class.__mapper__.primary_key[0])
@@ -152,11 +158,21 @@ class DirectMapping(_rdf.store.Store):
 
     @property
     def base_iri(self):
+        """The base IRI of this store.
+
+        This IRI is used as a prefix for the class, resource, and property IRIs
+        generated by this store's implementation of `direct mapping`_.
+
+        .. _direct mapping: http://www.w3.org/TR/rdb-direct-mapping/
+
+        :type: :obj:`str`
+
+        """
         return self._base_iri
 
     @base_iri.setter
     def _(self, value):
-        _require_isinstance(value, _iri_duck.UriReference)
+        _require_isinstance(value, _iri_goose.UriReference)
         self._base_iri = value
 
     def bind(self, prefix, namespace):
@@ -347,10 +363,11 @@ class DirectMapping(_rdf.store.Store):
 
         :return:
             The matching triples.
-        :rtype: ~[(:class:`rdflib.URIRef`,
+        :rtype: ~[(:class:`rdflib.URIRef` or :class:`rdflib.BNode`,
                    :class:`rdflib.URIRef`,
-                   :class:`rdflib.URIRef` or :class:`rdflib.Literal`
-                     or :class:`rdflib.Date` or :class:`rdflib.DateRange`)]
+                   :class:`rdflib.URIRef` or :class:`rdflib.BNode`
+                     or :class:`rdflib.Literal` or :class:`rdflib.Date`
+                     or :class:`rdflib.DateRange`)]
 
         """
 
@@ -1097,18 +1114,6 @@ class DirectMapping(_rdf.store.Store):
         return _rdf.URIRef(iri)
 
 
-class R2RML(_rdf.store.Store):
-
-    """
-
-    .. _R2RML: http://www.w3.org/TR/r2rml/
-
-
-    """
-
-    # FIXME
-
-
 def _orm_column_property_by_name(mapper):
     return _frozendict((prop.key, prop) for prop in mapper.column_attrs)
 
